@@ -29,28 +29,18 @@
 BEGIN_GNOME_DECLS
 
 /*
- * Callbacks
+ * Main control
  */
-extern void builder_about_cb         (GtkWidget *w, gpointer data);
-extern void builder_activate_help_cb (GtkWidget *w, gpointer data);
-extern void builder_quit_cb          (GtkWidget *w, gpointer data);
+GnomeDbControlInstance* builder_control_create_instance (GnomeDbControl *control);
 
 /*
  * Configuration
  */
 void builder_config_save (void);
 
-/*
- * Help system
- */
-extern void builder_help_init     (void);
-extern void builder_help_activate (void);
-
 /*
  * Global variables
  */
-extern GtkWidget* glb_mainwin;
-extern GtkWidget* glb_notebook;
 
 END_GNOME_DECLS
 
