@@ -58,6 +58,9 @@ static void open_connection_cb            (GtkWidget *w, GnomeDbControlInstance
 static void rollback_transaction_cb       (GtkWidget *w, GnomeDbControlInstance *control_instance);
 static void show_connection_properties_cb (GtkWidget *w, GnomeDbControlInstance *control_instance);
 
+static void do_copy_cb  (GnomeDbControlInstance *control_instance, connection_control_data_t *instance_data);
+static void do_cut_cb   (GnomeDbControlInstance *control_instance, connection_control_data_t *instance_data);
+static void do_paste_cb (GnomeDbControlInstance *control_instance, connection_control_data_t *instance_data);
 static void do_print_cb (GnomeDbControlInstance *control_instance, connection_control_data_t *instance_data);
 
 static void sql_clear_cb     (GtkWidget *w, connection_instance_data_t *instance_data);
@@ -392,6 +395,18 @@ connection_create_instance_cb (GnomeDbControl *control) {
 		                   "do_print",
 		                   GTK_SIGNAL_FUNC(do_print_cb),
 		                   (gpointer) control_data);
+		gtk_signal_connect(GTK_OBJECT(control_data->control_instance),
+		                   "do_cut_clipboard",
+		                   GTK_SIGNAL_FUNC(do_cut_cb),
+		                   (gpointer) control_data);
+		gtk_signal_connect(GTK_OBJECT(control_data->control_instance),
+		                   "do_copy_clipboard",
+		                   GTK_SIGNAL_FUNC(do_copy_cb),
+		                   (gpointer) control_data);
+		gtk_signal_connect(GTK_OBJECT(control_data->control_instance),
+		                   "do_paste_clipboard",
+		                   GTK_SIGNAL_FUNC(do_paste_cb),
+		                   (gpointer) control_data);
 	}
 	else gtk_object_destroy(GTK_OBJECT(tab));
 	
@@ -478,6 +493,57 @@ disconnect_cb (GtkWidget *w, GnomeDbControlInstance *control_instance) {
 	}
 }
 
+static void
+do_copy_cb (GnomeDbControlInstance *control_instance, connection_control_data_t *control_data) {
+	gint                        current_page;
+	GtkWidget*                  tab;
+	connection_instance_data_t* instance_data;
+	
+	g_return_if_fail(GNOME_DB_IS_CONTROL_INSTANCE(control_instance));
+	
+	instance_data = get_current_connection_from_control_instance(control_instance);
+	if (instance_data) {
+		current_page = gtk_notebook_get_current_page(GTK_NOTEBOOK(instance_data->tab));
+		tab = gtk_notebook_get_nth_page(GTK_NOTEBOOK(instance_data->tab), current_page);
+		if (tab == instance_data->sql_tab) sql_copy_cb(NULL, instance_data);
+		else if (tab == instance_data->browser_tab) ;
+	}
+}
+
+static void
+do_cut_cb (GnomeDbControlInstance *control_instance, connection_control_data_t *instance_data) {
+	gint                        current_page;
+	GtkWidget*                  tab;
+	connection_instance_data_t* instance_data;
+	
+	g_return_if_fail(GNOME_DB_IS_CONTROL_INSTANCE(control_instance));
+	
+	instance_data = get_current_connection_from_control_instance(control_instance);
+	if (instance_data) {
+		current_page = gtk_notebook_get_current_page(GTK_NOTEBOOK(instance_data->tab));
+		tab = gtk_notebook_get_nth_page(GTK_NOTEBOOK(instance_data->tab), current_page);
+		if (tab == instance_data->sql_tab) sql_cut_cb(NULL, instance_data);
+		else if (tab == instance_data->browser_tab) ;
+	}
+}
+
+static void
+do_paste_cb (GnomeDbControlInstance *control_instance, connection_control_data_t *instance_data) {
+	gint                        current_page;
+	GtkWidget*                  tab;
+	connection_instance_data_t* instance_data;
+	
+	g_return_if_fail(GNOME_DB_IS_CONTROL_INSTANCE(control_instance));
+	
+	instance_data = get_current_connection_from_control_instance(control_instance);
+	if (instance_data) {
+		current_page = gtk_notebook_get_current_page(GTK_NOTEBOOK(instance_data->tab));
+		tab = gtk_notebook_get_nth_page(GTK_NOTEBOOK(instance_data->tab), current_page);
+		if (tab == instance_data->sql_tab) sql_paste_cb(NULL, instance_data);
+		else if (tab == instance_data->browser_tab) ;
+	}
+}
+
 static void
 do_print_cb (GnomeDbControlInstance *control_instance, connection_control_data_t *instance_data) {
 	GtkWidget* dialog;
@@ -762,7 +828,7 @@ components_connection_init (void) {
 	if (!GNOME_DB_IS_CONTROL(connection_control)) {
 		gchar* oafiid;
 		
-		oafiid = g_strdup("OAFIID:control-factory:gnome-db-connection:c6967e5e-035e-48ff-9983-87966d81a0e2");
+		oafiid = g_strdup("OAFIID:GNOME_DB_Connection_ControlFactory");
 		
 		/* register factory */
 		connection_control = gnome_db_control_new(oafiid, connection_create_instance_cb);
