@@ -18,6 +18,8 @@
  
 #include <gnomedb-com.h>
 
+static guint prepare_app (void);
+
 int
 main (int argc, char *argv[])
 {
@@ -26,7 +28,15 @@ main (int argc, char *argv[])
   
   gnome_db_init("gnomedb-components", VERSION, argc, argv);
   
-  /* register components factory */
+  /* run application */
+  gnome_db_main(prepare_app);
+  return 0;
+}
+
+static guint
+prepare_app (void)
+{
+  /* register components factories */
   components_connection_init();
   components_designer_init();
   components_export_init();
@@ -34,7 +44,5 @@ main (int argc, char *argv[])
   components_import_init();
   components_log_init();
   
-  /* run application */
-  gnome_db_main(NULL);
-  return 0;
+  return FALSE;
 }
