@@ -26,6 +26,12 @@
 
 BEGIN_GNOME_DECLS
 
+/*
+ * Configuration
+ */
+GList* components_config_get_last_commands (void);
+void   components_config_add_last_command  (const gchar *cmd);
+
 /*
  * Connection pool
  */
@@ -34,10 +40,12 @@ Gda_Connection* components_connection_open (const gchar *name, const gchar *user
 /*
  * Components
  */
-extern void components_browser_init (void);
-extern void components_export_init  (void);
-extern void components_import_init  (void);
-extern void components_log_init     (void);
+void components_connection_init (void);
+void components_designer_init   (void);
+void components_export_init     (void);
+void components_help_init       (void);
+void components_import_init     (void);
+void components_log_init        (void);
 
 END_GNOME_DECLS
 
