@@ -17,19 +17,34 @@
  */
 
 #include <gnomedb-monikers.h>
-
-static BonoboGenericFactory* moniker_factory = NULL;
+#include <bonobo/bonobo-shlib-factory.h>
 
 /*
  * Private functions
  */
 static BonoboObject *
-database_moniker_resolve (GnomeDbMoniker *moniker, const gchar *requested_interface) {
+database_moniker_resolve (GnomeDbMoniker *moniker, const gchar *requested_interface)
+{
+	Bonobo_Moniker    corba_parent;
+	CORBA_Environment ev;
+	const gchar*      name;
+
 	g_return_val_if_fail(GNOME_DB_IS_MONIKER(moniker), NULL);
 	g_return_val_if_fail(requested_interface != NULL, NULL);
-	
+
+	CORBA_exception_init(&ev);
+
+	/* retrieve parent */
+	corba_parent = bonobo_moniker_get_parent(moniker, &ev);
+	if (BONOBO_EX(&ev))
+		return CORBA_OBJECT_NIL;
+	name = bonobo_moniker_get_name(moniker);
+
 	if (!strcmp(requested_interface, "IDL:Bonobo/Control:1.0")) {
 	}
+	else if (!strcmp(requested_interface, "IDL:Bonobo/PropertyBag:1.0")) {
+		/* return a property bag for the requested object */
+	}
 	
 	return NULL;
 }
@@ -54,15 +69,7 @@ database_moniker_factory (BonoboGenericFactory *factory, void *closure) {
 /*
  * Public functions
  */
-void
-monikers_database_init (void)
-{
-	/* create the factory */
-	if (!BONOBO_IS_GENERIC_FACTORY(moniker_factory)) {
-		moniker_factory = bonobo_generic_factory_new(GNOME_DB_OAFIID_MONIKER_DATABASE_FACTORY,
-		                                             database_moniker_factory,
-		                                             NULL);
-		if (!BONOBO_IS_GENERIC_FACTORY(moniker_factory))
-			g_error(_("Could not create Database Moniker factory"));
-	}
-}
+BONOBO_OAF_SHLIB_FACTORY(GNOME_DB_OAFIID_MONIKER_DATABASE_FACTORY,
+                          "GNOME-DB database moniker",
+                          database_moniker_factory,
+                          NULL)
