@@ -32,6 +32,9 @@ BEGIN_GNOME_DECLS
  */
 void fe_about_cb              (GtkWidget *w, gpointer user_data);
 void fe_activate_component_cb (GtkWidget *w, gpointer user_data);
+void fe_do_copy_clipboard_cb  (GtkWidget *w, gpointer user_data);
+void fe_do_cut_clipboard_cb   (GtkWidget *w, gpointer user_data);
+void fe_do_paste_clipboard_cb (GtkWidget *w, gpointer user_data);
 void fe_do_print_cb           (GtkWidget *w, gpointer user_data);
 void fe_preferences_cb        (GtkWidget *w, gpointer user_data);
 void fe_quit_cb               (GtkWidget *w, gpointer user_data);
