@@ -16,7 +16,7 @@
 #include <unistd.h>
 #include <bonobo/Bonobo.h>
 #include <bonobo/bonobo-object.h>
-#include <bonobo/bonobo-ui-xml.h>
+//#include <bonobo/bonobo-ui-xml.h>
 #include <bonobo/bonobo-ui-util.h>
 #include <bonobo/bonobo-ui-container.h>
 #include <bonobo/bonobo-ui-node.h>
