@@ -47,8 +47,9 @@ control_destroyed_cb (GnomeDbControl *control)
 static BonoboObject *
 control_factory_func (BonoboGenericFactory *factory, gpointer data)
 {
-  BonoboControl*  bonobo_control = NULL;
-  GnomeDbControl* control;
+  BonoboControl*          bonobo_control = NULL;
+  GnomeDbControl*         control;
+  GnomeDbControlInstance* control_instance;
   
   g_return_val_if_fail(BONOBO_IS_GENERIC_FACTORY(factory), NULL);
   g_return_val_if_fail(GNOME_DB_IS_CONTROL(data), NULL);
@@ -56,7 +57,7 @@ control_factory_func (BonoboGenericFactory *factory, gpointer data)
   control = GNOME_DB_CONTROL(data);
   if (control->priv->create_func)
     {
-      GnomeDbControlInstance* control_instance = control->priv->create_func(control);
+      control_instance = control->priv->create_func(control);
       if (GNOME_DB_IS_CONTROL_INSTANCE(control_instance))
         {
           bonobo_control = gnome_db_control_instance_get_bonobo_control(control_instance);
@@ -72,7 +73,7 @@ control_factory_func (BonoboGenericFactory *factory, gpointer data)
             }
         }
     }
-  return BONOBO_OBJECT(bonobo_control);
+  return BONOBO_OBJECT(control_instance);
 }
 
 static void
