@@ -35,15 +35,13 @@ typedef GnomeDbControlInstance* (*GnomeDbControlInstanceCreateFunc)(GnomeDbContr
 
 typedef struct _GnomeDbControlPrivate GnomeDbControlPrivate;
 
-struct _GnomeDbControl
-{
-  BonoboObject           object;
-  GnomeDbControlPrivate* priv;
+struct _GnomeDbControl {
+	BonoboObject           object;
+	GnomeDbControlPrivate* priv;
 };
 
-struct _GnomeDbControlClass
-{
-  BonoboObjectClass parent_class;
+struct _GnomeDbControlClass {
+	BonoboObjectClass parent_class;
 };
 
 GtkType         gnome_db_control_get_type (void);
