@@ -31,23 +31,21 @@ BEGIN_GNOME_DECLS
 typedef struct _GnomeDbDsnConfig      GnomeDbDsnConfig;
 typedef struct _GnomeDbDsnConfigClass GnomeDbDsnConfigClass;
 
-struct _GnomeDbDsnConfig
-{
-  GtkVBox    vbox;
-
-  /* private */
-  GtkWidget* gda_name_entry;
-  GtkWidget* provider_entry;
-  GtkWidget* dsn_entry;
-  GtkWidget* description_entry;
-  GtkWidget* user_entry;
-  GtkWidget* config_entry;
-  GtkWidget* global_button;
+struct _GnomeDbDsnConfig {
+	GtkVBox    vbox;
+	
+	/* private */
+	GtkWidget* gda_name_entry;
+	GtkWidget* provider_entry;
+	GtkWidget* dsn_entry;
+	GtkWidget* description_entry;
+	GtkWidget* user_entry;
+	GtkWidget* config_entry;
+	GtkWidget* global_button;
 };
 
-struct _GnomeDbDsnConfigClass
-{
-  GtkVBoxClass parent_class;
+struct _GnomeDbDsnConfigClass {
+	GtkVBoxClass parent_class;
 };
 
 guint        gnome_db_dsn_config_get_type (void);
@@ -60,6 +58,11 @@ gboolean     gnome_db_dsn_config_remove   (GnomeDbDsnConfig *dsnconf);
 const gchar* gnome_db_dsn_config_get_name (GnomeDbDsnConfig *dsnconf);
 void         gnome_db_dsn_config_set_name (GnomeDbDsnConfig *dsnconf, const gchar *name);
 
+const gchar* gnome_db_dsn_config_get_provider    (GnomeDbDsnConfig *dsnconf);
+const gchar* gnome_db_dsn_config_get_dsn         (GnomeDbDsnConfig *dsnconf);
+const gchar* gnome_db_dsn_config_get_description (GnomeDbDsnConfig *dsnconf);
+const gchar* gnome_db_dsn_config_get_user        (GnomeDbDsnConfig *dsnconf);
+
 END_GNOME_DECLS
 
 #endif
