@@ -1,19 +1,20 @@
 /* GNOME DB libary
  * Copyright (C) 1999 Rodrigo Moya
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * This Library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
+ * This Library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
  * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * License along with this Library; see the file COPYING.LIB.  If not,
+ * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
  
 #if !defined(__gnome_db_help_h__)
@@ -42,16 +43,20 @@ struct _GnomeDbHelp
 struct _GnomeDbHelpClass
 {
   GtkVBoxClass parent_class;
+  
+  void         (*page_loaded)(GnomeDbHelp *help, const gchar *url);
 };
 
-GtkType    gnome_db_help_get_type   (void);
-GtkWidget* gnome_db_help_new        (void);
+GtkType      gnome_db_help_get_type   (void);
+GtkWidget*   gnome_db_help_new        (void);
 
-void       gnome_db_help_show_url   (GnomeDbHelp *help, const gchar *url);
-void       gnome_db_help_go_home    (GnomeDbHelp *help);
-void       gnome_db_help_go_back    (GnomeDbHelp *help);
-void       gnome_db_help_go_forward (GnomeDbHelp *help);
+void         gnome_db_help_show_url   (GnomeDbHelp *help, const gchar *url);
+void         gnome_db_help_go_home    (GnomeDbHelp *help);
+void         gnome_db_help_go_back    (GnomeDbHelp *help);
+void         gnome_db_help_go_forward (GnomeDbHelp *help);
+
+const gchar* gnome_db_help_get_home (void);
 
 END_GNOME_DECLS
 
-#endif
\ No newline at end of file
+#endif
