@@ -34,18 +34,20 @@
 #include <gnome-db-browser.h>
 #include <gnome-db-combo.h>
 #include <gnome-db-config.h>
+#include <gnome-db-dataset.h>
+#include <gnome-db-designer.h>
 #include <gnome-db-dsn-config.h>
+#include <gnome-db-entry.h>
 #include <gnome-db-error.h>
 #include <gnome-db-error-dlg.h>
 #include <gnome-db-grid.h>
 #include <gnome-db-icon-list.h>
-#include <gnome-db-dataset.h>
-#include <gnome-db-log-viewer.h>
+#include <gnome-db-label.h>
 #include <gnome-db-list.h>
+#include <gnome-db-log-viewer.h>
 #include <gnome-db-login.h>
 #include <gnome-db-login-dlg.h>
 #include <gnome-db-report.h>
-#include <gnome-db-designer.h>
 #include <gnome-db-shortcut.h>
 #include <gnome-db-util.h>
 #include <gnome-db-window.h>
