@@ -30,7 +30,7 @@ main (int argc, char *argv[])
   gnome_db_init("gnomedb-mgr", VERSION, argc, argv);
   
   /* register control */
-  manager_control = gnome_db_control_new("OAFIID:control-factory:gnome-db-manager:69c316f9-944f-4a7d-8637-0fa545439138",
+  manager_control = gnome_db_control_new("OAFIID:GNOME_DB_Manager_ControlFactory",
                                          manager_control_create_instance_cb);
   if (!GNOME_DB_IS_CONTROL(manager_control))
     {
